==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-checkbox.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { IgrCheckboxBase } from "./igr-checkbox-base";
import { Checkbox } from "./Checkbox";
import { IgcCheckboxComponent, defineComponents } from "igniteui-webcomponents";
import { ensureBool } from "igniteui-react-core";
/**
 * A check box allowing single values to be selected/deselected.
*/
var IgrCheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrCheckbox, _super);
    function IgrCheckbox(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcCheckboxComponent);
        return _this;
    }
    IgrCheckbox.prototype.createImplementation = function () {
        return new Checkbox();
    };
    Object.defineProperty(IgrCheckbox.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCheckbox.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrCheckbox.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-checkbox", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrCheckbox.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrCheckbox.prototype, "indeterminate", {
        /**
         * Draws the checkbox in indeterminate state.
        */
        get: function () {
            return this.i.z;
        },
        set: function (v) {
            this.i.z = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrCheckbox;
}(IgrCheckboxBase));
export { IgrCheckbox };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-checkbox.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { IgrCheckboxBase } from "./igr-checkbox-base";
import { Checkbox } from "./Checkbox";
import { IgcCheckboxComponent, defineComponents } from "igniteui-webcomponents";
import { ensureBool } from "igniteui-react-core";
/**
 * A check box allowing single values to be selected/deselected.
*/
var IgrCheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrCheckbox, _super);
    function IgrCheckbox(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcCheckboxComponent);
        return _this;
    }
    IgrCheckbox.prototype.createImplementation = function () {
        return new Checkbox();
    };
    Object.defineProperty(IgrCheckbox.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCheckbox.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrCheckbox.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-checkbox", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrCheckbox.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrCheckbox.prototype, "indeterminate", {
        /**
         * Draws the checkbox in indeterminate state.
        */
        get: function () {
            return this.i.ab;
        },
        set: function (v) {
            this.i.ab = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrCheckbox;
}(IgrCheckboxBase));
export { IgrCheckbox };
